@@ -1,6 +1,5 @@
 #![deny(warnings)]
 
-use chrono::Utc;
 use clap::Clap;
 use near_syn::{parse_rust, ts::TS, Args};
 use std::env;
@@ -14,7 +13,7 @@ fn main() {
 
     for file_name in args.files {
         let ast = parse_rust(file_name);
-        ts.ts_unit(&ast);
+        ts.ts_items(&ast.items);
     }
     ts.ts_main_type();
     ts.ts_contract_methods();
